@@ -22,11 +22,13 @@ import inspect
 import itertools
 from operator import attrgetter
 
-from . import caching, compatibility
+from . import caching
 from .currying import post_curry
 
+sentinel = object()
 
-def native_GetAttrProxy(target):
+
+def GetAttrProxy(target):
     def reflected_getattr(self, attr):
         return getattr(object.__getattribute__(self, target), attr)
     return reflected_getattr
@@ -43,7 +45,7 @@ def DirProxy(target):
     return combined_dir
 
 
-def native_contains(self, key):
+def contains(self, key):
     """
     return True if key is in self, False otherwise
     """
@@ -55,7 +57,7 @@ def native_contains(self, key):
         return False
 
 
-def native_get(self, key, default=None):
+def get(self, key, default=None):
     """
     return ``default`` if ``key`` is not in self, else the value associated with ``key``
     """
@@ -64,10 +66,9 @@ def native_get(self, key, default=None):
     except KeyError:
         return default
 
-_sentinel = object()
 
 _attrlist_getter = attrgetter("__attr_comparison__")
-def native_generic_attr_eq(inst1, inst2):
+def generic_attr_eq(inst1, inst2):
     """
     compare inst1 to inst2, returning True if equal, False if not.
 
@@ -76,13 +77,13 @@ def native_generic_attr_eq(inst1, inst2):
     if inst1 is inst2:
         return True
     for attr in _attrlist_getter(inst1):
-        if getattr(inst1, attr, _sentinel) != \
-            getattr(inst2, attr, _sentinel):
+        if getattr(inst1, attr, sentinel) != \
+            getattr(inst2, attr, sentinel):
             return False
     return True
 
 
-def native_generic_attr_ne(inst1, inst2):
+def generic_attr_ne(inst1, inst2):
     """
     compare inst1 to inst2, returning True if different, False if equal.
 
@@ -91,12 +92,12 @@ def native_generic_attr_ne(inst1, inst2):
     if inst1 is inst2:
         return False
     for attr in _attrlist_getter(inst1):
-        if getattr(inst1, attr, _sentinel) != getattr(inst2, attr, _sentinel):
+        if getattr(inst1, attr, sentinel) != getattr(inst2, attr, sentinel):
             return True
     return False
 
 
-def native_reflective_hash(attr):
+def reflective_hash(attr):
     """
     default __hash__ implementation that returns a pregenerated hash attribute
 
@@ -108,7 +109,7 @@ def native_reflective_hash(attr):
     return __hash__
 
 
-def _native_internal_jit_attr(
+def _internal_jit_attr(
         func, attr_name, singleton=None,
         use_cls_setattr=False, use_singleton=True, doc=None):
     """Object implementing the descriptor protocol for use in Just In Time access to attributes.
@@ -117,18 +118,19 @@ def _native_internal_jit_attr(
     instead of directly consuming this.
     """
     doc = getattr(func, '__doc__', None) if doc is None else doc
-    class _native_internal_jit_attr(_raw_native_internal_jit_attr):
+
+    class _internal_jit_attr(_raw_internal_jit_attr):
         __doc__ = doc
         __slots__ = ()
-    kls = _native_internal_jit_attr
+    kls = _internal_jit_attr
 
     return kls(
         func, attr_name, singleton=singleton, use_cls_setattr=use_cls_setattr,
         use_singleton=use_singleton)
 
 
-class _raw_native_internal_jit_attr:
-    """See _native_internal_jit_attr; this is an implementation detail of that"""
+class _raw_internal_jit_attr:
+    """See _internal_jit_attr; this is an implementation detail of that"""
 
     __slots__ = ("storage_attr", "function", "_setter", "singleton", "use_singleton")
 
@@ -176,22 +178,6 @@ class _raw_native_internal_jit_attr:
         return obj
 
 
-try:
-    # pylint: disable=unused-import
-    from ._klass import (
-        GetAttrProxy, contains, get,
-        generic_eq as generic_attr_eq, generic_ne as generic_attr_ne,
-        reflective_hash, _internal_jit_attr)
-except ImportError:
-    GetAttrProxy = native_GetAttrProxy
-    contains = native_contains
-    get = native_get
-    generic_attr_eq = native_generic_attr_eq
-    generic_attr_ne = native_generic_attr_ne
-    reflective_hash = native_reflective_hash
-    _internal_jit_attr = _native_internal_jit_attr
-
-
 def generic_equality(name, bases, scope, real_type=type,
                      eq=generic_attr_eq, ne=generic_attr_ne):
     """
@@ -261,7 +247,7 @@ def generic_gt(self, other):
     return self.__cmp__(other) > 0
 
 
-def inject_richcmp_methods_from_cmp(scope, inject_always=False):
+def inject_richcmp_methods_from_cmp(scope):
     """
     class namespace modifier injecting richcmp methods that rely on __cmp__ for py3k
     compatibility
@@ -283,7 +269,7 @@ def inject_richcmp_methods_from_cmp(scope, inject_always=False):
     ...   # exist (__cmp__ would be sufficient).
     ...
     ...   # add the generic rich comparsion methods to the local class namespace
-    ...   inject_richcmp_methods_from_cmp(locals(), True)
+    ...   inject_richcmp_methods_from_cmp(locals())
     ...
     ...   def __init__(self, a, b):
     ...     self.a, self.b = a, b
@@ -298,12 +284,8 @@ def inject_richcmp_methods_from_cmp(scope, inject_always=False):
     >>> assert foo(1, 1).__eq__(foo(1, 1))
 
     :param scope: the modifiable scope of a class namespace to work on
-    :param inject_always: normally injection is only done if it's py3k; if True,
-        it'll always inject the rich comparison methods
     """
 
-    if not (inject_always or compatibility.is_py3k):
-        return
     for key, func in (("__lt__", generic_lt), ("__le__", generic_le),
                       ("__eq__", generic_eq), ("__ne__", generic_ne),
                       ("__ge__", generic_ge), ("__gt__", generic_gt)):
@@ -372,6 +354,7 @@ class chained_getter(metaclass=partial(generic_equality, real_type=caching.WeakI
     def __call__(self, obj):
         return self.getter(obj)
 
+
 static_attrgetter = attrgetter
 instance_attrgetter = chained_getter
 
@@ -387,6 +370,7 @@ class _singleton_kls:
 
 _uncached_singleton = _singleton_kls
 
+
 def jit_attr(func, kls=_internal_jit_attr, uncached_val=_uncached_singleton):
     """
     decorator to JIT generate, and cache the wrapped functions result in
@@ -403,6 +387,7 @@ def jit_attr(func, kls=_internal_jit_attr, uncached_val=_uncached_singleton):
     attr_name = "_%s" % func.__name__
     return kls(func, attr_name, uncached_val, False)
 
+
 def jit_attr_none(func, kls=_internal_jit_attr):
     """
     Version of :py:func:`jit_attr` decorator that forces the uncached_val
@@ -414,6 +399,7 @@ def jit_attr_none(func, kls=_internal_jit_attr):
     """
     return jit_attr(func, kls=kls, uncached_val=None)
 
+
 def jit_attr_named(stored_attr_name, use_cls_setattr=False, kls=_internal_jit_attr,
                    uncached_val=_uncached_singleton, doc=None):
     """
@@ -424,6 +410,7 @@ def jit_attr_named(stored_attr_name, use_cls_setattr=False, kls=_internal_jit_at
     """
     return post_curry(kls, stored_attr_name, uncached_val, use_cls_setattr, doc=doc)
 
+
 def jit_attr_ext_method(func_name, stored_attr_name,
                         use_cls_setattr=False, kls=_internal_jit_attr,
                         uncached_val=_uncached_singleton, doc=None):
@@ -471,6 +458,7 @@ def cached_property(func, kls=_internal_jit_attr, use_cls_setattr=False):
     return kls(func, func.__name__, None, use_singleton=False,
                use_cls_setattr=use_cls_setattr)
 
+
 def cached_property_named(name, kls=_internal_jit_attr, use_cls_setattr=False):
     """
     variation of `cached_property`, just with the ability to explicitly set the attribute name
@@ -496,6 +484,7 @@ def cached_property_named(name, kls=_internal_jit_attr, use_cls_setattr=False):
     """
     return post_curry(kls, name, use_singleton=False, use_cls_setattr=False)
 
+
 def alias_attr(target_attr):
     """
     return a property that will alias access to target_attr
@@ -599,6 +588,7 @@ def steal_docs(target, ignore_missing=False, name=None):
             except AttributeError:
                 if not ignore_missing:
                     raise
+                return functor
         else:
             obj = target
         functor.__doc__ = obj.__doc__
@@ -670,9 +660,11 @@ def patch(target, external_decorator=None):
 def _immutable_setattr(self, attr, value):
     raise AttributeError(self, attr)
 
+
 def _immutable_delattr(self, attr):
     raise AttributeError(self, attr)
 
+
 def immutable_instance(name, bases, scope, real_type=type):
     """metaclass that makes instances of this class effectively immutable
 
@@ -682,6 +674,7 @@ def immutable_instance(name, bases, scope, real_type=type):
     inject_immutable_instance(scope)
     return real_type(name, bases, scope)
 
+
 def inject_immutable_instance(scope):
     """inject immutable __setattr__ and __delattr__ implementations
 
